@@ -16,9 +16,15 @@
 #include "FollowLocationJob.h"
 
 #include "Project.h"
-#include "rct/SignalSlot.h"
 #include "RTags.h"
-#include "Server.h"
+#include "FileMap.h"
+#include "QueryMessage.h"
+#include "Symbol.h"
+#include "clang-c/Index.h"
+#include "rct/Flags.h"
+#include "rct/List.h"
+#include "rct/Set.h"
+#include "rct/String.h"
 
 FollowLocationJob::FollowLocationJob(Location loc,
                                      const std::shared_ptr<QueryMessage> &query,
