@@ -15,9 +15,21 @@
 
 #include "IncludePathJob.h"
 
+#include <stddef.h>
+#include <cstdint>
+#include <functional>
+#include <utility>
+
 #include "Project.h"
 #include "RTags.h"
-#include "Server.h"
+#include "FileMap.h"
+#include "QueryMessage.h"
+#include "Symbol.h"
+#include "clang-c/Index.h"
+#include "rct/Flags.h"
+#include "rct/List.h"
+#include "rct/Path.h"
+#include "rct/String.h"
 
 IncludePathJob::IncludePathJob(const Location loc, const std::shared_ptr<QueryMessage> &query, const std::shared_ptr<Project> &project)
     : QueryJob(query, project, QuietJob), location(loc)
