@@ -16,10 +16,16 @@
 #ifndef Location_h
 #define Location_h
 
-#include <algorithm>
 #include <assert.h>
 #include <clang-c/Index.h>
 #include <stdio.h>
+#include <stdint.h>
+#include <stdlib.h>
+#include <string.h>
+#include <algorithm>
+#include <functional>
+#include <type_traits>
+#include <utility>
 #if defined(OS_Linux)
 #include <linux/limits.h>
 #elif defined(OS_Darwin)
@@ -27,6 +33,7 @@
 #endif
 #ifndef RTAGS_SINGLE_THREAD
 #include <mutex>
+
 #define LOCK() const std::lock_guard<std::mutex> lock(sMutex)
 #else
 #define LOCK() do {} while (0)
@@ -38,6 +45,7 @@
 #include "rct/Serializer.h"
 #include "rct/String.h"
 #include "rct/StackBuffer.h"
+#include "rct/Hash.h"
 
 static inline int intCompare(uint32_t l, uint32_t r)
 {
