@@ -1,4 +1,4 @@
-/* This file is part of RTags (http://rtags.net).
+/* This file is part of RTags (https://github.com/Andersbakken/rtags).
 
    RTags is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with RTags.  If not, see <http://www.gnu.org/licenses/>. */
+   along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
 #ifndef OutputMessage_h
 #define OutputMessage_h
@@ -32,12 +32,12 @@ public:
     LogLevel level() const { return mLevel; }
     Flags<QueryMessage::Flag> flags() const { return mFlags; }
 
-    void encode(Serializer &serializer) const
+    void encode(Serializer &serializer) const override
     {
         serializer << mCommandLine << mLevel << mFlags;
     }
 
-    void decode(Deserializer &deserializer)
+    void decode(Deserializer &deserializer) override
     {
         deserializer >> mCommandLine >> mLevel >> mFlags;
     }
