@@ -15,14 +15,18 @@
 
 #include "QueryJob.h"
 
-#include <regex>
+#include <assert.h>
+#include <ctype.h>
+#include <string.h>
 
 #include "Project.h"
 #include "QueryMessage.h"
 #include "RTags.h"
-#include "Server.h"
 #include "rct/Connection.h"
-#include "rct/EventLoop.h"
+#include "FileMap.h"
+#include "Symbol.h"
+#include "rct/Log.h"
+#include "rct/Value.h"
 
 QueryJob::QueryJob(const std::shared_ptr<QueryMessage> &query,
                    const std::shared_ptr<Project> &proj,
@@ -208,7 +212,7 @@ bool QueryJob::write(Location location, Flags<WriteFlag> flags)
     return write(out, flags);
 }
 
-bool QueryJob::write(const Symbol &symbol, Flags<WriteFlag> writeFlags)
+String QueryJob::symbolToString(const Symbol &symbol) const
 {
     Flags<Symbol::ToStringFlag> toStringFlags;
     if (queryFlags() & QueryMessage::SymbolInfoIncludeTargets)
@@ -226,14 +230,17 @@ bool QueryJob::write(const Symbol &symbol, Flags<WriteFlag> writeFlags)
     if (queryFlags() & (QueryMessage::ContainingFunctionLocation | QueryMessage::JSON | QueryMessage::Elisp))
         toStringFlags |= Symbol::IncludeContainingFunctionLocation;
 
-    if (symbol.isNull())
-        return false;
+    if (symbol.isNull()) {
+        return String();
+    }
 
-    if (!filterLocation(symbol.location))
-        return false;
+    if (!filterLocation(symbol.location)) {
+        return String();
+    }
 
-    if (!mKindFilters.filter(symbol))
-        return false;
+    if (!mKindFilters.filter(symbol)) {
+        return String();
+    }
 
     String out;
     if (queryFlags() & (QueryMessage::Elisp | QueryMessage::JSON)) {
@@ -246,7 +253,15 @@ bool QueryJob::write(const Symbol &symbol, Flags<WriteFlag> writeFlags)
     } else {
         out = symbol.toString(project(), toStringFlags, locationToStringFlags(), mPieceFilters);
     }
-    return write(out, writeFlags | Unfiltered);
+    return out;
+}
+
+bool QueryJob::write(const Symbol &symbol, Flags<WriteFlag> writeFlags)
+{
+    String out = symbolToString(symbol);
+    if (!out.isEmpty())
+        return write(out, writeFlags | Unfiltered);
+    return true;
 }
 
 bool QueryJob::filter(const String &value) const
