@@ -17,8 +17,21 @@
 
 #include <stdio.h>
 #include <sys/ioctl.h>
+#include <assert.h>
+#include <ctype.h>
+#include <errno.h>
+#include <limits.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <functional>
+#include <initializer_list>
+#include <regex>
+#include <type_traits>
+#include <unordered_map>
+#include <utility>
+#include <vector>
 
-#include "FileMap.h"
 #include "IndexMessage.h"
 #include "LogOutputMessage.h"
 #include "rct/Connection.h"
@@ -26,10 +39,17 @@
 #include "rct/Log.h"
 #include "rct/QuitMessage.h"
 #include "rct/Rct.h"
-#include "rct/StopWatch.h"
 #include "rct/OnDestruction.h"
 #include "RTags.h"
-#include "RTagsLogOutput.h"
+#include "Location.h"
+#include "clang-c/Index.h"
+#include "rct/Hash.h"
+#include "rct/Map.h"
+#include "rct/Message.h"
+#include "rct/ResponseMessage.h"
+#include "rct/Serializer.h"
+#include "rct/SignalSlot.h"
+#include "rct/SocketClient.h"
 
 #define DEFAULT_CONNECT_TIMEOUT 1000
 #define XSTR(s) #s
@@ -112,7 +132,7 @@ std::initializer_list<CommandLineParser::Option<RClient::OptionType> > opts = {
     { RClient::DebugLocations, "debug-locations", 0, CommandLineParser::Optional, "Manipulate debug locations." },
     { RClient::Validate, "validate", 0, CommandLineParser::NoValue, "Validate database files for current project." },
     { RClient::Tokens, "tokens", 0, CommandLineParser::Required, "Dump tokens for file. --tokens file.cpp:123-321 for range." },
-    { RClient::DeadFunctions, "find-dead-functions", 0, CommandLineParser::Optional, "Find functions declared/defined in the current file that are never in the project." },
+    { RClient::DeadFunctions, "find-dead-functions", 0, CommandLineParser::Optional, "Find functions declared/defined in the current file that are never used in the project." },
 
     { RClient::None, String(), 0, CommandLineParser::NoValue, "" },
     { RClient::None, String(), 0, CommandLineParser::NoValue, "Command flags:" },
@@ -137,7 +157,7 @@ std::initializer_list<CommandLineParser::Option<RClient::OptionType> > opts = {
     { RClient::MatchRegex, "match-regexp", 'Z', CommandLineParser::NoValue, "Treat various text patterns as regexps (-P, -i, -V, -F)." },
     { RClient::MatchCaseInsensitive, "match-icase", 'I', CommandLineParser::NoValue, "Match case insensitively" },
     { RClient::AbsolutePath, "absolute-path", 'K', CommandLineParser::NoValue, "Print files with absolute path." },
-    { RClient::SocketFile, "socket-file", 'n', CommandLineParser::Required, "Use this socket file (default ~/.rdm)." },
+    { RClient::SocketFile, "socket-file", 'n', CommandLineParser::Required, "Use this socket file (default is XDG_RUNTIME_DIR/rdm.socket else ~/.rdm)" },
     { RClient::SocketAddress, "socket-address", 0, CommandLineParser::Required, "Use this host:port combination (instead of --socket-file)." },
     { RClient::Timeout, "timeout", 'y', CommandLineParser::Required, "Max time in ms to wait for job to finish (default no timeout)." },
     { RClient::FindVirtuals, "find-virtuals", 'k', CommandLineParser::NoValue, "Use in combinations with -R or -r to show other implementations of this function." },
@@ -885,6 +905,7 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
         case Status: {
             QueryMessage::Type queryType = QueryMessage::Invalid;
             bool resolve = true;
+
             switch (type) {
             case CheckReindex:
                 queryType = QueryMessage::CheckReindex;
@@ -936,7 +957,9 @@ CommandLineParser::ParseStatus RClient::parse(size_t argc, char **argv)
                 Path p(arg);
                 if (resolve && p.exists()) {
                     p.resolve();
-                    addQuery(queryType, std::move(p), QueryMessage::HasLocation);
+                }
+                if (resolve) {
+                    addQuery(queryType, std::move(p));
                 } else {
                     addQuery(queryType, std::move(arg));
                 }
