@@ -16,9 +16,14 @@
 #include "RTags.h"
 
 #include <dirent.h>
-#include <fcntl.h>
 #include <fnmatch.h>
-#include <sys/types.h>
+#include <limits.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <map>
+#include <unordered_map>
 #if defined(OS_FreeBSD) || defined(OS_DragonFly)
 #include <sys/sysctl.h>
 #endif
@@ -30,15 +35,16 @@
 #include "LogOutputMessage.h"
 #include "QueryMessage.h"
 #include "rct/Rct.h"
-#include "rct/Connection.h"
-#include "rct/StopWatch.h"
-#include "Server.h"
-#include "ClangIndexer.h"
-#include "Project.h"
 #include "VisitFileMessage.h"
 #include "VisitFileResponseMessage.h"
 #include "RTagsVersion.h"
-#include <clang-c/CXCompilationDatabase.h>
+#include "Diagnostic.h"
+#include "IndexMessage.h"
+#include "Sandbox.h"
+#include "clang-c/CXErrorCode.h"
+#include "clang-c/Index.h"
+#include "rct/Date.h"
+#include "rct/Message.h"
 
 namespace RTags {
 String versionString()
@@ -518,7 +524,7 @@ String cursorToString(CXCursor cursor, const Flags<CursorToStringFlags> flags)
         ret += " def";
 
     if (flags & IncludeUSR) {
-        const String usr = eatString(clang_getCursorUSR(clang_getCanonicalCursor(cursor)));
+        const String usr = RTags::usr(cursor);
         if (!usr.isEmpty()) {
             ret += " " + usr;
         }
@@ -527,7 +533,7 @@ String cursorToString(CXCursor cursor, const Flags<CursorToStringFlags> flags)
     if (flags & IncludeSpecializedUsr) {
         const CXCursor general = clang_getSpecializedCursorTemplate(cursor);
         if (!clang_Cursor_isNull(general)) {
-            const String usr = eatString(clang_getCursorUSR(clang_getCanonicalCursor(general)));
+            const String usr = RTags::usr(general);
             if (!usr.isEmpty()) {
                 ret += " " + usr;
             }
@@ -564,7 +570,16 @@ String cursorToString(CXCursor cursor, const Flags<CursorToStringFlags> flags)
         const char *data = clang_getCString(file);
         if (data && *data) {
             ret += ' ';
-            ret += data;
+            if (flags & RealPathCursorPath) {
+                char buf[PATH_MAX];
+                if (realpath(data, buf)) {
+                    ret += buf;
+                } else {
+                    ret += data;
+                }
+            } else {
+                ret += data;
+            }
             ret += ':';
             ret += String::number(line);
             ret += ':';
@@ -708,6 +723,26 @@ static inline Diagnostic::Flag convertDiagnosticType(CXDiagnosticSeverity sev)
     return type;
 }
 
+static inline int fixitFileId(const Location &loc)
+{
+    if (!loc.fileId())
+        return 0;
+
+    const Path path = loc.path();
+    if (path.isSystem())
+        return 0;
+
+    // we keep getting fixits for xmmintrin.h, this solves the issue
+    // when it isn't a "system header" ideally we would identify
+    // system headers in a different way I guess
+    const char *fn = path.fileName();
+    assert(fn);
+    if (!strcmp(fn, "xmmintrin.h") || !strcmp(fn, "emmintrin.h")) {
+        return 0;
+    }
+    return loc.fileId();
+}
+
 void DiagnosticsProvider::diagnose()
 {
     const uint32_t sourceFile = sourceFileId();
@@ -792,7 +827,7 @@ void DiagnosticsProvider::diagnose()
         for (size_t j=0; j<diagCount; ++j) {
             CXDiagnostic diag = diagnostic(u, j);
             const CXSourceLocation diagLoc = clang_getDiagnosticLocation(diag);
-            const uint32_t fileId = createLocation(diagLoc, nullptr).fileId();
+            const uint32_t fileId = fixitFileId(createLocation(diagLoc, nullptr));
             if (!fileId) {
                 clang_disposeDiagnostic(diag);
                 // error() << "Couldn't get location for diagnostics" << clang_getCursor(tu, diagLoc) << fileId << mSource.fileId
@@ -978,6 +1013,7 @@ CXCursor findFirstChild(CXCursor parent)
 
 struct FindChildVisitor
 {
+    CXChildVisitResult result;
     CXCursorKind kind;
     String name;
     CXCursor cursor;
@@ -998,20 +1034,20 @@ static CXChildVisitResult findChildVisitor(CXCursor cursor, CXCursor, CXClientDa
             return CXChildVisit_Break;
         }
     }
-    return CXChildVisit_Continue;
+    return u->result;
 }
 
-CXCursor findChild(CXCursor parent, CXCursorKind kind)
+CXCursor findChild(CXCursor parent, CXCursorKind kind, CXChildVisitResult mode)
 {
-    FindChildVisitor u = { kind, String(), clang_getNullCursor() };
+    FindChildVisitor u = { mode, kind, String(), clang_getNullCursor() };
     if (!clang_isInvalid(clang_getCursorKind(parent)))
         clang_visitChildren(parent, findChildVisitor, &u);
     return u.cursor;
 }
 
-CXCursor findChild(CXCursor parent, const String &name)
+CXCursor findChild(CXCursor parent, const String &name, CXChildVisitResult mode)
 {
-    FindChildVisitor u = { CXCursor_FirstInvalid, name, clang_getNullCursor() };
+    FindChildVisitor u = { mode, CXCursor_FirstInvalid, name, clang_getNullCursor() };
     if (!clang_isInvalid(clang_getCursorKind(parent)))
         clang_visitChildren(parent, findChildVisitor, &u);
     return u.cursor;
@@ -1242,4 +1278,38 @@ int cursorArguments(const CXCursor &cursor, List<CXCursor> *args)
     return numArgs;
 }
 
+String usr(const CXCursor &cursor)
+{
+    String str = RTags::eatString(clang_getCursorUSR(clang_getCanonicalCursor(cursor)));
+    size_t idx = 0;
+    while (true) {
+        idx = str.indexOf("<", idx);
+        if (idx == String::npos)
+            break;
+        if (idx > 9 && !strncmp(str.c_str() + idx - 8, "operator", 8) && !std::isalnum(str[idx - 9]) && str[idx - 9] != '_') {
+            idx += 2;
+            continue;
+        }
+        size_t templateIdx = 0;
+        size_t start = ++idx;
+        while (idx < str.size()) {
+            if (str[idx] == '<') {
+                start = ++idx;
+            } else if (str[idx] == ',') {
+                assert(str[idx + 1] == ' ');
+                const String replacement = String::format("T%zu", templateIdx++);
+                const ssize_t diff = replacement.size() - (idx - start);
+                str.replace(start, idx - start, replacement);
+                idx += diff + 2;
+                start = idx;
+            } else if (str[idx] == '>') {
+                str.replace(start, idx - start, String::format("T%zu", templateIdx++));
+                break;
+            } else {
+                ++idx;
+            }
+        }
+    }
+    return str;
+}
 }
