@@ -15,14 +15,28 @@
 
 #include "StatusJob.h"
 
-#include <clang-c/Index.h>
+#include <stdint.h>
+#include <strings.h>
+#include <map>
+#include <unordered_map>
+#include <utility>
 
 #include "CompilerManager.h"
-#include "JobScheduler.h"
 #include "Project.h"
-#include "rct/Process.h"
 #include "RTags.h"
 #include "Server.h"
+#include "FileMap.h"
+#include "IndexParseData.h"
+#include "Location.h"
+#include "QueryMessage.h"
+#include "Source.h"
+#include "Symbol.h"
+#include "rct/Flags.h"
+#include "rct/Hash.h"
+#include "rct/List.h"
+#include "rct/Log.h"
+#include "rct/Path.h"
+#include "rct/Set.h"
 
 const char *StatusJob::delimiter = "*********************************";
 StatusJob::StatusJob(const std::shared_ptr<QueryMessage> &q, const std::shared_ptr<Project> &project)
