@@ -13,9 +13,27 @@
    You should have received a copy of the GNU General Public License
    along with RTags.  If not, see <https://www.gnu.org/licenses/>. */
 
+#include <assert.h>
+#include <stdint.h>
+#include <string.h>
+#include <functional>
+#include <limits>
+#include <memory>
+#include <string>
+
 #include "RTags.h"
 #include "Symbol.h"
 #include "Project.h"
+#include "FileMap.h"
+#include "Location.h"
+#include "clang-c/Index.h"
+#include "rct/Flags.h"
+#include "rct/List.h"
+#include "rct/Log.h"
+#include "rct/Path.h"
+#include "rct/Set.h"
+#include "rct/String.h"
+#include "rct/Value.h"
 
 uint16_t Symbol::targetsValue() const
 {
