@@ -16,22 +16,36 @@
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <assert.h>
+#include <errno.h>
+#include <limits.h>
+#include <string.h>
+#include <strings.h>
+#include <unistd.h>
+#include <algorithm>
+#include <functional>
+#include <initializer_list>
+#include <memory>
+#include <utility>
 #ifdef OS_Darwin
 #include <sys/resource.h>
 #endif
 
 #include "rct/EventLoop.h"
-#include "rct/FileSystemWatcher.h"
 #include "rct/Log.h"
 #include "rct/Process.h"
 #include "rct/rct-config.h"
 #include "rct/Rct.h"
-#include "rct/StackBuffer.h"
-#include "rct/Thread.h"
 #include "rct/ThreadPool.h"
 #include "RTags.h"
 #include "CommandLineParser.h"
 #include "Server.h"
+#include "Source.h"
+#include "rct/Flags.h"
+#include "rct/List.h"
+#include "rct/Path.h"
+#include "rct/Set.h"
+#include "rct/String.h"
 #ifdef HAVE_BACKTRACE
 #include <execinfo.h>
 #endif
@@ -184,6 +198,7 @@ enum OptionType {
     AllowWpedantic,
     AllowWErrorAndWFatalErrors,
     EnableCompilerManager,
+    DisableCompilerManager,
     EnableNDEBUG,
     Progress,
     MaxFileMapCacheSize,
@@ -258,7 +273,7 @@ int main(int argc, char** argv)
     serverOpts.maxFileMapScopeCacheSize = DEFAULT_RDM_MAX_FILE_MAP_CACHE_SIZE;
     serverOpts.errorLimit = DEFAULT_ERROR_LIMIT;
     serverOpts.rpNiceValue = INT_MIN;
-    serverOpts.options = Server::Wall|Server::SpellChecking|Server::CompletionDiagnostics;
+    serverOpts.options = Server::Wall|Server::SpellChecking|Server::CompletionDiagnostics|Server::EnableCompilerManager;
     serverOpts.maxCrashCount = DEFAULT_MAX_CRASH_COUNT;
     serverOpts.completionCacheSize = DEFAULT_COMPLETION_CACHE_SIZE;
     serverOpts.maxIncludeCompletionDepth = DEFAULT_MAX_INCLUDE_COMPLETION_DEPTH;
@@ -273,10 +288,10 @@ int main(int argc, char** argv)
     // #endif
     serverOpts.dataDir = String::format<128>("%s.rtags", Path::home().constData());
     if (!serverOpts.dataDir.exists()) {
-         const char * dataDir = getenv("XDG_CACHE_HOME");
-         serverOpts.dataDir = dataDir ? dataDir : Path::home() + ".cache";
-         serverOpts.dataDir += "/rtags/";
-         serverOpts.dataDir.mkdir(Path::Recursive);
+        const char * dataDir = getenv("XDG_CACHE_HOME");
+        serverOpts.dataDir = dataDir ? dataDir : Path::home() + ".cache";
+        serverOpts.dataDir += "/rtags/";
+        serverOpts.dataDir.mkdir(Path::Recursive);
     }
     Path logFile;
     Flags<LogFlag> logFlags = DontRotate|LogStderr;
@@ -301,16 +316,15 @@ int main(int argc, char** argv)
         { NoWall, "no-Wall", 'W', CommandLineParser::NoValue, "Don't use -Wall." },
         { Weverything, "Weverything", 'u', CommandLineParser::NoValue, "Use -Weverything." },
         { Verbose, "verbose", 'v', CommandLineParser::NoValue, "Change verbosity, multiple -v's are allowed." },
-        { JobCount, "job-count", 'j', CommandLineParser::Required, String::format("Spawn this many concurrent processes for indexing (default %d).",
-                                                                                  std::max(2, ThreadPool::idealThreadCount())) },
+        { JobCount, "job-count", 'j', CommandLineParser::Required, String::format("Spawn this many concurrent processes for indexing (default to the number of available processing units or 2 otherwise).") },
         { Test, "test", 't', CommandLineParser::Required, "Run this test." },
-        { TempDir, "tempdir", 0, CommandLineParser::Required, "Use this directory for temporary files. Clang generates a lot of these and rtags will periodically clean out this directory. Default is $TMPDIR/rtags/" },
+        { TempDir, "tempdir", 0, CommandLineParser::Required, "Use this directory for temporary files. Clang generates a lot of these and rtags will periodically clean out this directory (default is $TMPDIR/rtags/)" },
         { TestTimeout, "test-timeout", 'z', CommandLineParser::Required, "Timeout for test to complete." },
         { CleanSlate, "clean-slate", 'C', CommandLineParser::NoValue, "Clear out all data." },
         { DisableSigHandler, "disable-sighandler", 'x', CommandLineParser::NoValue, "Disable signal handler to dump stack for crashes." },
         { Silent, "silent", 'S', CommandLineParser::NoValue, "No logging to stdout/stderr." },
-        { ExcludeFilter, "exclude-filter", 'X', CommandLineParser::Required, String::format("Files to exclude from rdm, default \"%s\".", DEFAULT_EXCLUDEFILTER) },
-        { SocketFile, "socket-file", 'n', CommandLineParser::Required, "Use this file for the server socket (default ~/.rdm)." },
+        { ExcludeFilter, "exclude-filter", 'X', CommandLineParser::Required, String::format("Files to exclude from rdm (default \"%s\".)", DEFAULT_EXCLUDEFILTER) },
+        { SocketFile, "socket-file", 'n', CommandLineParser::Required, "Use this file for the server socket (default is XDG_RUNTIME_DIR/rdm.socket else ~/.rdm)." },
         { DataDir, "data-dir", 'd', CommandLineParser::Required, "Use this directory to store persistent data (default $XDG_CACHE_HOME/rtags otherwise ~/.cache/rtags)." },
         { IgnorePrintfFixits, "ignore-printf-fixits", 'F', CommandLineParser::NoValue, "Disregard any clang fixit that looks like it's trying to fix format for printf and friends." },
         { ErrorLimit, "error-limit", 'f', CommandLineParser::Required, String::format("Set error limit to argument (-ferror-limit={arg} (default %d).", DEFAULT_ERROR_LIMIT) },
@@ -344,7 +358,8 @@ int main(int argc, char** argv)
         { MaxIncludeCompletionDepth, "max-include-completion-depth", 0, CommandLineParser::Required, String::format("Max recursion depth for header completion (default %d).", DEFAULT_MAX_INCLUDE_COMPLETION_DEPTH) },
         { AllowWpedantic, "allow-Wpedantic", 'P', CommandLineParser::NoValue, "Don't strip out -Wpedantic. This can cause problems in certain projects." },
         { AllowWErrorAndWFatalErrors, "allow-Werror", 0, CommandLineParser::NoValue, "Don't strip out -Werror and -Wfatal-errors. By default these are stripped out. " },
-        { EnableCompilerManager, "enable-compiler-manager", 'R', CommandLineParser::NoValue, "Query compilers for their actual include paths instead of letting clang use its own." },
+        { EnableCompilerManager, "enable-compiler-manager", 'R', CommandLineParser::NoValue, "Query compilers for their actual include paths instead of letting clang use its own. This is now the default. Kept for backwards compatibility." },
+        { DisableCompilerManager, "disable-compiler-manager", 0, CommandLineParser::NoValue, "Do not query compilers for their actual include paths instead of letting clang use its own." },
         { EnableNDEBUG, "enable-NDEBUG", 'g', CommandLineParser::NoValue, "Don't remove -DNDEBUG from compile lines." },
         { Progress, "progress", 'p', CommandLineParser::NoValue, "Report compilation progress in diagnostics output." },
         { MaxFileMapCacheSize, "max-file-map-cache-size", 'y', CommandLineParser::Required, String::format("Max files to cache per query (Should not exceed maximum number of open file descriptors allowed per process) (default %d).", DEFAULT_RDM_MAX_FILE_MAP_CACHE_SIZE) },
@@ -384,7 +399,7 @@ int main(int argc, char** argv)
         switch (type) {
         case None:
         case Noop:
-        break;
+            break;
         case Help: {
             CommandLineParser::help(stdout, Rct::executablePath().fileName(), opts);
             return { String(), CommandLineParser::Parse_Ok }; }
@@ -627,6 +642,9 @@ int main(int argc, char** argv)
         case EnableCompilerManager: {
             serverOpts.options |= Server::EnableCompilerManager;
             break; }
+        case DisableCompilerManager: {
+            serverOpts.options &= ~Server::EnableCompilerManager;
+            break; }
         case EnableNDEBUG: {
             serverOpts.options |= Server::EnableNDEBUG;
             break; }
